==> knative-model-5.1.2-sources.jar: annotations/io/fabric8/knative/serving/v1beta1/RevisionListBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RevisionListBuilder extends io.fabric8.knative.serving.v1beta1.RevisionListFluentImpl<io.fabric8.knative.serving.v1beta1.RevisionListBuilder> implements VisitableBuilder<io.fabric8.knative.serving.v1beta1.RevisionList,io.fabric8.knative.serving.v1beta1.RevisionListBuilder> {

    io.fabric8.knative.serving.v1beta1.RevisionListFluent<?> fluent;
    Boolean validationEnabled;

    public RevisionListBuilder() {
        this(true);
    }

    public RevisionListBuilder(Boolean validationEnabled) {
        this(new RevisionList(), validationEnabled);
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionListFluent<?> fluent) {
        this(fluent, true);
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new RevisionList(), validationEnabled);
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionListFluent<?> fluent,io.fabric8.knative.serving.v1beta1.RevisionList instance) {
        this(fluent, instance, true);
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionListFluent<?> fluent,io.fabric8.knative.serving.v1beta1.RevisionList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionList instance) {
        this(instance,true);
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.serving.v1beta1.EditableRevisionList build() {
        EditableRevisionList buildable = new EditableRevisionList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RevisionListBuilder that = (RevisionListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/serving/v1beta1/RevisionListBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RevisionListBuilder extends io.fabric8.knative.serving.v1beta1.RevisionListFluentImpl<io.fabric8.knative.serving.v1beta1.RevisionListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.knative.serving.v1beta1.RevisionList,io.fabric8.knative.serving.v1beta1.RevisionListBuilder> {

    io.fabric8.knative.serving.v1beta1.RevisionListFluent<?> fluent;
    Boolean validationEnabled;

    public RevisionListBuilder() {
        this(true);
    }

    public RevisionListBuilder(Boolean validationEnabled) {
        this(new RevisionList(), validationEnabled);
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionListFluent<?> fluent) {
        this(fluent, true);
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new RevisionList(), validationEnabled);
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionListFluent<?> fluent,io.fabric8.knative.serving.v1beta1.RevisionList instance) {
        this(fluent, instance, true);
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionListFluent<?> fluent,io.fabric8.knative.serving.v1beta1.RevisionList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionList instance) {
        this(instance,true);
    }

    public RevisionListBuilder(io.fabric8.knative.serving.v1beta1.RevisionList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.serving.v1beta1.EditableRevisionList build() {
        EditableRevisionList buildable = new EditableRevisionList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RevisionListBuilder that = (RevisionListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
